@@ -10,12 +10,12 @@ return(tempf)}));
 tempi = as.data.frame(table(tempzz));
 tempj = unlist(lapply(common_words_new, function(x){tempoo = which(as.character(tempi[,1]) == x   ); if (length(tempoo) != 0) return(tempoo)}));
 tempk = tempi[-tempj,];
-templ = as.character(HGNCdata$Approved.Symbol);
+templ = as.character(HGNCdata$symbol);
 tempm = unlist(lapply(templ,function(x){return(which(x == as.character(tempk$tempzz) ))}));
 tempn = tempk[tempm,]
 tempn2=tempn[order(as.numeric(tempn$Freq), decreasing = T),]
 tempo = unlist(lapply( as.character(tempn2$tempzz), function(x){return(which(x == templ))}));
-Genes = as.character(HGNCdata$Approved.Name[tempo]);
+Genes = as.character(HGNCdata$name[tempo]);
 data_table= cbind(as.character(tempn2$tempzz), Genes, tempn2$Freq);
 colnames(data_table)=c("Gene_symbol", "   Genes", "Freq");
 write.table(data_table, file = "table.txt", sep = "\t", row.names = F); return(data_table) }
